@@ -1,19 +1,16 @@
 import requests
 
-from .base import PybitesSearch, ContentPiece
+from .base import ContentPiece, PybitesSearch
 
 ARTICLE_ENDPOINT = "https://codechalleng.es/api/articles/"
 
 
 class ArticleSearch(PybitesSearch):
-
     def match_content(self, search: str) -> list[ContentPiece]:
-        entries = requests.get(ARTICLE_ENDPOINT).json()
+        entries = requests.get(ARTICLE_ENDPOINT, timeout=5).json()
         results = []
         for entry in entries:
-            if search.lower() in (
-                entry["title"] + entry["summary"]
-            ).lower():
+            if search.lower() in (entry["title"] + entry["summary"]).lower():
                 results.append(
                     ContentPiece(
                         title=entry["title"],
@@ -24,6 +21,6 @@ class ArticleSearch(PybitesSearch):
 
 
 if __name__ == "__main__":
-    search = ArticleSearch()
-    results = search.match_content("django")
-    print(results)
+    searcher = ArticleSearch()
+    results = searcher.match_content("django")
+    searcher.show_matches(results)
